# Changelog
All notable changes to this project will be documented in this file.
The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.1.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [0.1.0] - 2024-12-5

### Added

- Initial release

## [0.2.0] - 2025-02-07

### Added

- Added linear algorithms for Halfspace and Hyperplane problems
- Better GPU/CPU differentiaton
- More proximity measure options
- More example files
- General code cleanup

### Removed
